import {
	IDisposable, DisposableDelegate
} from '@phosphor/disposable';

import {
	JupyterFrontEnd, JupyterFrontEndPlugin
} from '@jupyterlab/application';

import {
	ToolbarButton
} from '@jupyterlab/apputils';

import {
	DocumentRegistry
} from '@jupyterlab/docregistry';

import {
	NotebookPanel, INotebookModel
} from '@jupyterlab/notebook';

import {
	Mode, CodeMirrorEditor
} from '@jupyterlab/codemirror'


import './codemirror-finesse';

/**
 * The plugin registration information.
 */
const plugin: JupyterFrontEndPlugin<void> = {
	activate,
	id: 'my-extension-name:buttonPlugin',
	autoStart: true
};


/**
 * A notebook widget extension that adds a button to the toolbar.
 */
export
class ButtonExtension implements DocumentRegistry.IWidgetExtension<NotebookPanel, INotebookModel> {
	/**
	 * Create a new extension object.
	 */
	createNew(panel: NotebookPanel, context: DocumentRegistry.IContext<INotebookModel>): IDisposable {
		let callback = () => {
			console.log(Mode.getModeInfo());
			panel.content.widgets.forEach(cell => {
				(cell.editor as CodeMirrorEditor).setOption("mode", "finesse");
			});
			//NotebookActions.runAll(panel.content, context.session);
		};
		let button = new ToolbarButton({
			className: 'myButton',
			iconClassName: 'fa fa-fast-forward',
			onClick: callback,
			tooltip: 'Run All'
		});

		panel.toolbar.insertItem(0, 'runAll', button);
		return new DisposableDelegate(() => {
			button.dispose();
		});
	}
}

/**
 * Activate the extension.
 */
function activate(app: JupyterFrontEnd) {
	app.docRegistry.addWidgetExtension('Notebook', new ButtonExtension());
};


/**
 * Export the plugin as default.
 */
export default plugin;
